setup_pyproject
===============

This is the documentation of **setup_pyproject**.


Contents
--------

.. toctree::
   :maxdepth: 2
   
   Module Reference <_rst/modules>


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
